/// <reference types="react" />
import { CalendarViewType, DateCell, MonthMatrix, WeekDayType, WeekRow } from './models';
export interface UseCalendarPlugins {
    month?: Array<(<T>(data: MonthMatrix) => MonthMatrix & T)> | null;
    week?: Array<(<T>(data: WeekRow) => WeekRow & T)> | null;
    date?: Array<(<T>(data: DateCell) => DateCell & T)> | null;
}
export interface UseCalendarOptions {
    defaultDate?: Date | number | string;
    defaultWeekStart?: WeekDayType;
    defaultViewType?: CalendarViewType;
    plugins?: UseCalendarPlugins;
}
export default function useCalendar({ defaultDate, defaultWeekStart, defaultViewType, }?: UseCalendarOptions): {
    calendar: {
        viewType: CalendarViewType;
        cursorDate: Date;
        year: number;
        month: number;
        day: number;
        weekStartsOn: WeekDayType;
        startWeekdayInMonth: number;
        weeksInMonth: number;
        weekendDays: {
            value: Date;
        }[];
        getCurrentWeekIndex: () => number;
        getCurrentDateIndex: () => WeekDayType;
        getDateCellByIndex: (weekIndex: number, dayIndex: number) => DateCell;
    };
    headers: {
        weekDays: ({
            value: Date;
        } & {
            key: string;
        })[];
    };
    body: {
        value: {
            key: string;
            value: (DateCell & {
                date: number;
                isCurrentMonth: boolean;
                isCurrentDate: boolean;
            } & {
                key: string;
            })[];
        }[];
    } | {
        value: {
            key: string;
            value: (DateCell & {
                date: number;
                isCurrentMonth: boolean;
                isCurrentDate: boolean;
            } & {
                key: string;
            })[];
        }[];
    } | {
        value: {
            key: string;
            value: (DateCell & {
                date: number;
                isCurrentMonth: boolean;
                isCurrentDate: boolean;
            } & {
                key: string;
            })[];
        }[];
    };
    getBody: (viewType: CalendarViewType) => {
        value: {
            key: string;
            value: (DateCell & {
                date: number;
                isCurrentMonth: boolean;
                isCurrentDate: boolean;
            } & {
                key: string;
            })[];
        }[];
    } | {
        value: {
            key: string;
            value: (DateCell & {
                date: number;
                isCurrentMonth: boolean;
                isCurrentDate: boolean;
            } & {
                key: string;
            })[];
        }[];
    } | {
        value: {
            key: string;
            value: (DateCell & {
                date: number;
                isCurrentMonth: boolean;
                isCurrentDate: boolean;
            } & {
                key: string;
            })[];
        }[];
    };
    navigation: {
        toNext: () => void;
        toPrev: () => void;
        setToday: () => void;
        setDate: (date: Date) => void;
    };
    view: {
        type: CalendarViewType;
        setViewType: import("react").Dispatch<import("react").SetStateAction<CalendarViewType>>;
        setWeekStartsOn: import("react").Dispatch<import("react").SetStateAction<WeekDayType>>;
        isMonthView: boolean;
        isWeekView: boolean;
        isDayView: boolean;
        showMonthView: () => void;
        showWeekView: () => void;
        showDayView: () => void;
    };
};
